0.10.21 UPD 28 août Windows, Linux

Téléchargement Team Red Miner

TeamRedMiner — Guide complet

Options :

  -a, --algo=ALGORITHM      Sélectionne l'algorithme de minage.  Disponibles actuellement :
                              ethash            (eth, etp, autres)
                              etchash           (etc, alias de -a ethash --eth_variant_mode=etchash)
                              kawpow            (ravencoin)
                              firopow           (firo)
                              mtp_firopow       (choisit firopow ou mtp et arrête le mineur au moment du fork du 26 octobre 2021)
                              autolykos2        (ergo)
                              verthash          (vtc)
                              ton               (ton)
                              kas               (kaspa)
                              nimiq             (nimiq)
                              lyra2z
                              phi2              (lux, argoneum)
                              lyra2rev3
                              x16r
                              x16rv2
                              x16s              (pgn, xsh)
                              x16rt             (gin)
                              mtp               (zcoin/firo avant le fork firopow)
                              cuckatoo31_grin   (grin)
                              cuckarood29_grin  (grin)
                              cnv8
                              cnr               (ancien monero)
                              cnv8_half         (stellite, masari)
                              cnv8_dbl          (x-cash)
                              cnv8_rwz          (graft)
                              cnv8_trtl         (ancien turtlecoin, loki)
                              cnv8_upx2         (uplexa)
                              cn_heavy          (CN heavy classique)
                              cn_haven          (haven)
                              cn_saber          (bittube)
                              cn_conceal        (conceal)
                              trtl_chukwa       (turtlecoin)
                              trtl_chukwa2      (turtlecoin)

  -h, --help                Affiche ce message d'aide et quitte.
      --debug               Active la sortie du journal de débogage.
      --hardware=HW_LIST    Indique, sous forme de liste séparée par des virgules, les types de matériel que le mineur doit essayer d'utiliser.
                              Les valeurs prises en charge actuellement sont 'gpu' et 'fpga'.  Par exemple :
                                --hardware=gpu,fpga
      --benchmark           Active le mode benchmark.  Tous les pools définis sont ignorés et un pool interne fictif unique
                              est ajouté automatiquement.  Pour tester des algorithmes comme eth et kawpow à des époques et hauteurs
                              de bloc précises, vous devez aussi ajouter des arguments propres à l'algorithme, comme --eth_epoch=456 et --prog_height=123456.
      --disable_colors      Désactive les couleurs dans la console.
      --force_colors        Force l'affichage des couleurs dans la console même si le terminal ne semble pas les prendre en charge.
      --api_listen=IP:PORT  Active l'API compatible sgminer. IP:PORT est facultatif. S'il est indiqué, le couple IP:PORT
                              détermine la ou les interfaces et le port d'écoute. Par défaut : 127.0.0.1:4028. Pour
                              un accès externe, utilisez par exemple 0.0.0.0:4028. Il est aussi possible de n'indiquer que le
                              port, par exemple 4029.  Cet argument peut désormais être répété pour définir plusieurs points d'accès.
      --api2_listen=IP:PORT Active un second port d'API pour les configurations de minage dual.  Ce point d'accès fournit les données de
                              l'algorithme dual, comme si deux instances distinctes du mineur tournaient en parallèle.  La
                              valeur par défaut est 127.0.0.1:4029, c'est-à-dire le port 4029 et non 4028.  Pour indiquer votre
                              propre valeur, l'argument a le même format que --api_listen.  Cet argument peut
                               désormais être répété pour définir plusieurs points d'accès.
      --cm_api_listen=IP:PORT Active l'API compatible Claymore. IP:PORT est facultatif. S'il est indiqué, le couple IP:PORT
                              détermine la ou les interfaces et le port d'écoute. Par défaut : 127.0.0.1:3333. Pour
                              un accès externe, utilisez par exemple 0.0.0.0:3333. Il est aussi possible de n'indiquer que le
                              port, par exemple 3334.
      --cm_api_password=PSW Définit le mot de passe requis pour l'interface d'API compatible CM.
      --log_file(=FILENAME) Active l'enregistrement de la sortie du mineur dans le fichier indiqué par FILENAME.  Si aucun nom de fichier
                              n'est indiqué, le mineur écrit dans trm_<algo>_<yyyymmdd_hhmmss>.log dans le répertoire
                              de travail courant.  Si le fichier journal existe déjà, le mineur écrit à la suite.
  -l, --log_interval=SEC    Définit l'intervalle, en secondes, de calcul de la moyenne et d'affichage du hashrate des GPU.
                              SEC définit l'intervalle en secondes et doit être > 0.
      --log_rotate=SZ[,CNT] Active la rotation des journaux. La valeur SZ définit la taille du journal au-delà de laquelle un nouveau fichier
                              est créé.  La valeur SZ accepte les suffixes 'k', 'M' et 'G', qui multiplient la
                              valeur respectivement par 1024, 1048576 et 1073741824. La valeur facultative CNT définit le
                              nombre maximal d'anciens fichiers journaux à conserver.  Par exemple, l'option '--log_rotate=4M,16'
                              fait passer le mineur à un nouveau fichier journal dès que le fichier actuel dépasse
                              4194304 octets ; le mineur conserve alors les 16 derniers fichiers de ce type et supprime
                              les plus anciens.
      --short_stats         Désactive l'affichage complet de l'état des GPU à chaque affichage du hashrate, comme avant la 0.7.10.
      --dev_location=LOC    Sélectionne une région précise pour la connexion des frais de développeur. N'utilisez cette option que si
                              le mineur signale des problèmes persistants de connexion pour les frais de développeur. La gestion des
                              connexions fonctionne normalement bien partout. Options disponibles :
                              world     - N'importe où dans le monde sauf en Chine continentale.
                              non-gcp   - Pays où l'accès aux services Google est bloqué (par ex. Iran, Cuba).
                              cn        - Chine continentale.
                              eu        - UE, Russie, Ukraine et pays voisins.
                              us        - États-Unis, Canada, Amérique centrale et du Sud.
                              asia      - Asie hors Chine.
      --enable_compute      (Windows uniquement) Active le mode compute et désactive le crossfire sur les GPU concernés.
      --long_timestamps     Active les horodatages à la microseconde dans les journaux au lieu de la seconde.
      --restart_gpus        (Windows uniquement) Redémarre tous les GPU configurés avant le minage, c'est-à-dire désactive puis réactive le périphérique PCI.
      --uac                 (Windows uniquement) Active l'élévation de privilèges lorsque le mineur exécute des tâches comme le redémarrage des GPU.
                              Vous pouvez toujours l'éviter en lançant directement le mineur en tant qu'administrateur.  Cela
                              déclenche l'invite d'élévation standard de Windows, vous devez donc être présent pour cliquer sur 'Oui'.
                              Si cette option n'est pas activée, les tâches nécessitant des privilèges administrateur échoueront lorsque le
                              mineur tourne sous un compte utilisateur standard.
      --high_score          Affiche dans les statistiques les 15 meilleurs shares trouvés depuis le démarrage du mineur.
                              Remarque : cela n'est peut-être pas disponible pour tous les algorithmes.
      --allow_dup_bus_ids   Autorise plusieurs GPU à utiliser le même identifiant de bus PCI.  À n'utiliser que pour les cartes Radeon Pro Duo
                              et matériel similaire ; sinon, c'est généralement le signe d'un environnement OpenCL défectueux.
      --dns_https=URL       Active la résolution DNS des pools via DNS-over-HTTPS.  C'est une fonctionnalité expérimentale.  TRM
                              ne prend en charge que la variante basée sur JSON, pas le mécanisme défini plus tard dans la RFC8484.  Vous devez
                              fournir l'URL https complète, nom de la méthode compris.  Il est possible d'indiquer des noms d'hôte
                              plutôt que des adresses IP brutes, mais ces noms d'hôte seront résolus par le DNS du système.
                              Voici quelques exemples dont le fonctionnement a été vérifié :

                              --dns_https=https://8.8.8.8/resolve           (Google DNS)
                              --dns_https=https://9.9.9.9:5053/dns-query    (Quad9)
                              --dns_https=https://1.1.1.1/dns-query         (Cloudflare DNS service)
      --dns_https_sni=HOST  Lorsque l'argument --dns_https est utilisé, le comportement par défaut consiste à ne pas envoyer de SNI dans la
                              connexion SSL/TLS.  Avec cet argument, vous pouvez forcer l'envoi d'un SNI quelconque.  Notez
                              qu'il s'agit d'un argument réseau avancé dont la plupart des utilisateurs n'ont pas besoin.
      --kernel_vm_mode=X    (Linux uniquement). Automatise la configuration des paramètres du noyau nécessaires dans /etc/default/grub sur les
                              systèmes Linux basés sur Debian/Ubuntu.  Cela couvre la plupart des distributions de minage.  Le système peut être redémarré
                              automatiquement via /sbin/reboot lorsque les paramètres du noyau sont modifiés.  Si les bons
                              paramètres sont déjà en place, le mineur et le script auxiliaire ne font rien. Cet
                              argument peut donc toujours figurer sur la ligne de commande.  Valeurs possibles :
                                N  -  aucun mode configuré, supprime les paramètres existants du mode C ou R.  Pas de redémarrage en cas de modification.
                                C  -  ancien mode C pour Radeon VII.  Pas de redémarrage en cas de modification.
                                R  -  nouveau mode R pour tous les GPU sauf Polaris.  Pas de redémarrage en cas de modification.
                                RN -  aucun mode configuré, supprime les paramètres existants du mode C ou R.  Redémarre en cas de modification.
                                RC -  ancien mode C pour Radeon VII.  Redémarre en cas de modification.
                                RR -  nouveau mode R pour tous les GPU sauf Polaris.  Redémarre en cas de modification.
      --kernel_vm_mode_script=X  (Linux uniquement).  Indique le script à appeler pour appliquer les nouveaux paramètres de mode du noyau.
                              Le script doit se comporter comme le script TRM par défaut fourni dans l'archive du mineur,
                              nommé ubuntu_mode_script.sh.  Cet argument n'est normalement pas nécessaire.
      --gpu_sdma=on|off     Indique si le pilote utilise des opérations sdma directes pour copier la mémoire vers/depuis
                              le GPU. Cet argument n'est utile que dans des situations très particulières. Par exemple, l'AMD BC-250
                              ne prend pas en charge sdma et nécessite --gpu_sdma=off. Si le système se bloque dès l'initialisation
                              du GPU alors que d'autres mineurs ou d'anciennes versions de TRM fonctionnent, essayez --gpu_sdma=off.
                              Ce paramètre est un réglage d'environnement et s'applique à tous les GPU.

Options de configuration du pool :

  -o, --url=URL             Définit l'URL du pool.  Les URL stratum+tcp et stratum+ssl sont actuellement prises en charge.
                              Chaque nouvelle occurrence de cette option crée une nouvelle configuration de pool.
                              Les options propres à chaque pool (comme -u, -p) doivent être indiquées explicitement
                              à nouveau pour chaque nouveau pool.  (Voir l'exemple de fichier start_multipool.sh/bat)
                              L'option --pool_strategy définit la stratégie multi-pool du mineur.
                              Il existe aussi une prise en charge spéciale des configurations SSL/TLS avancées, où vous devez
                              transmettre un nom d'hôte SNI au point d'accès SSL. C'est par exemple nécessaire pour les points
                              d'accès SSL qui servent de frontend à plusieurs hôtes et doivent savoir pour lequel
                              fournir un certificat. Dans ce cas, utilisez le format suivant :
                              -o stratum+ssl://pool.tunnel.com/pool.realhostname.com:3333
                              Le mineur se connectera à pool.tunnel.com:3333 mais transmettra pool.realhostname.com comme nom d'hôte
                              SNI lors de la phase de négociation SSL. Les deux noms d'hôte peuvent bien sûr aussi être identiques.
  -u, --user=USERNAME       Définit le nom d'utilisateur pour l'authentification sur le pool.
  -p, --pass=PASSWORD       Définit le mot de passe pour l'authentification sur le pool.
      --pool_force_ensub    Force l'envoi d'une requête extranonce subscribe aux pools compatibles inconnus du mineur.
      --pool_no_ensub       Empêche le mineur d'envoyer une requête extranonce subscribe au pool.
      --pool_broken_rpc     Indique au mineur de n'autoriser qu'une seule requête rpc en attente sur la connexion
                              au pool.  C'est un contournement pour les pools qui ne respectent pas la spécification json rpc
                              concernant les identifiants rpc.
      --pool_ratio=RATIO    Définit la répartition du hashrate entre les pools lorsque plusieurs pools sont utilisés avec les
                              stratégies 'load_balance' ou 'quota' (voir --pool_strategy).  Par défaut, tous les
                              pools ont un ratio de 1.  Par exemple, si vous donnez à cette option la valeur 2 sur
                              un seul pool, celui-ci recevra deux fois plus de hashrate que les autres pools,
                              puisque leur ratio restera à la valeur par défaut de 1.
      --pool_debug          Enregistre tout le trafic échangé avec le pool.

Options globales du pool :

      --pool_connect_TO=SEC Définit le délai d'attente pour la connexion à un pool. SEC est le temps d'attente en
                              secondes. Par défaut : 10.
      --pool_rpc_TO=SEC     Définit combien de temps le mineur attend la réponse du pool à un RPC.  Passé ce
                              délai, le mineur se reconnecte au pool.  SEC est le temps d'attente en secondes.
                              Par défaut : 60.
      --pool_max_rejects=N  Si un pool rejette N shares d'affilée, la connexion au pool est réinitialisée. Cela protège
                              contre les pools qui invalident les sessions de minage sans déconnecter l'utilisateur.
                              Valeur par défaut : 5.
      --pool_share_limit_ms=N  Si un pool met plus de N ms à accepter ou rejeter un share, la connexion actuelle
                              est coupée puis rétablie.  C'est utile pour les pools dont certains serveurs ont
                              souvent des problèmes : en se reconnectant, on est redirigé par l'équilibrage de charge vers un autre serveur,
                              si possible meilleur.  Par défaut : aucun délai.
      --pool_strategy=STRAT Définit la stratégie de choix des pools lorsque plusieurs pools sont configurés.  Les valeurs
                              possibles sont : priority, load_balance, quota et min_epoch.  Par défaut : priority.
                              priority : le mineur utilise les pools dans l'ordre de la liste et ne passe
                                au pool suivant que si le précédent ne parvient pas à établir de connexion.
                              load_balance : le mineur répartit équitablement le hashrate entre tous les pools
                                actuellement connectés.  La répartition du hashrate entre pools se règle avec --pool_ratio.
                              quota : le mineur répartit équitablement le nombre total de hashs effectués entre
                                tous les pools.  Si un pool se déconnecte puis se reconnecte, le mineur lui envoie
                                du hashrate jusqu'à ce que le total de hashs de chaque pool soit équilibré.
                                La répartition du hashrate entre pools se règle avec --pool_ratio.
                              min_epoch : stratégie de bascule ETH + ZIL.  Le mineur mine toujours l'époque la plus basse
                                parmi tous les pools connectés et, en cas d'égalité, le premier pool connecté.
                                Indiquez donc votre pool de minage ETH comme premier pool (principal), puis le pool ZIL
                                comme second pool.  Vous pouvez aussi utiliser le nom 'eth_zil' pour cette stratégie.
      --no_ntime_roll       Empêche le mineur de modifier ntime dans l'en-tête de bloc ; seule la valeur
                              fournie par le pool est utilisée. Nécessaire sur certains pools pour miner x16rt.
      --no_stale_submit     Empêche le mineur d'envoyer des shares qui ne correspondent pas au job le plus récent du pool.

Options GPU :

      --platform=INDEX      Définit l'index de la plateforme OpenCL à utiliser. Si elle n'est pas indiquée, la plateforme est
                              détectée automatiquement. Sous Linux avec plusieurs plateformes, la seule configuration prise en charge consiste à ne pas
                              utiliser l'argument --platform mais à ajouter --bus_reorder.
  -d, --devices=DEVLIST     Définit les GPU à utiliser parmi la liste détectée. DEVLIST est une liste d'index de
                              périphériques séparés par des virgules, par ex. -d 0,1,2,4.  Si rien n'est indiqué, tous
                              les périphériques de la ou des plateformes sont utilisés.  REMARQUE : par défaut, les périphériques sont triés
                              selon l'ordre du bus pcie. Utilisez --list_devices pour afficher les index.
      --init_style=1/2/3    Indique le mode d'initialisation (1 par défaut) :
                              1 : un GPU à la fois, tous initialisés avant de commencer à miner.
                              2 : trois GPU à la fois, tous initialisés avant de commencer à miner.
                              3 : tous les GPU en parallèle, le minage commence immédiatement.
      --pcie_fmt=FORMAT     Définit le format d'affichage des numéros de bus pcie.  Les valeurs acceptées pour FORMAT sont
                              'hex' ou 'dec'.  Par défaut : dec sous Windows et hex sous Linux.
      --bus_reorder         Trie les périphériques détectés ou indiqués selon leur identifiant de bus pcie.  Si aucune
                              plateforme n'est indiquée, les périphériques sont récupérés sur toutes les plateformes AMD OpenCL
                              détectées.  Remarque : depuis la version v0.7.0, c'est le comportement par défaut.
      --opencl_order        Trie les périphériques détectés ou indiqués dans l'ordre où OpenCL les présente.
      --list_devices        Liste les périphériques disponibles pour la plateforme détectée ou indiquée, puis quitte
                              immédiatement.  Le tri par bus est appliqué à l'ordre affiché.
      --nr_cu_override=X,Y,... Remplace le nombre d'unités de calcul (CU) par GPU tel que présenté par l'API OpenCL. C'est
                              surtout utile pour les Vega 64 flashées avec un BIOS de 56, pour lesquelles le pilote
                              indique 56 CU au lieu du nombre réel.  Indiquez comme valeur de l'argument une liste, séparée par des virgules,
                              du nombre de CU à utiliser pour chaque GPU.  Vous pouvez sauter des GPU et n'êtes pas
                              obligé d'indiquer une valeur pour tous les GPU du rig.  Exemple pour un rig mixte avec deux Vega
                              aux index 1 et 3 et deux autres GPU : --nr_cu_override=,64,,64.  Vous pouvez vérifier votre
                              argument en ajoutant aussi --list_devices avant de lancer le minage.

Options de contrôle des fréquences et tensions (Windows uniquement, fonctionnalité BETA) :

                              Le mineur offre des fonctions de base pour régler les fréquences du cœur et de la mémoire et leurs
                              tensions respectives, ainsi que pour choisir parmi les timings intégrés au pilote Windows.  Pour chaque
                              argument disponible ci-dessous, vous indiquez les valeurs des GPU du rig dans une liste séparée
                              par des virgules.  Certains arguments ne sont pas utilisés pour certains GPU.  Vous pouvez sauter des GPU dans la liste.
                              Le mineur définit et utilise toujours le p-state le plus élevé pour le cœur et la mémoire des GPU GCN
                              (Polaris, Vega).  Notez que les GPU Rx Vega _doivent_ avoir une modification de la powerplay table
                              pour le p-state mémoire p2 avant de pouvoir tourner à une tension inférieure à 900mV.  De plus, les GPU Big Navi
                              nécessitent toujours un outil comme MorePowerTool pour modifier la powerplay table, par exemple
                              pour pouvoir définir une tension plus basse.  Le mineur _pourrait_ prendre en charge les fonctions
                              liées à la powerplay table à l'avenir.
      --clk_debug                 Active l'affichage au démarrage des journaux liés au réglage des fréquences/tensions/timings.
      --clk_core_mhz=MHZ1,MHZ2,... Définit la fréquence du cœur par GPU, en MHz.
      --clk_core_mv=MV1,MV2,...    Définit la tension du cœur par GPU, en mV.
      --clk_mem_mhz=MHZ1,MHZ2,...  Définit la fréquence de la mémoire par GPU, en MHz.
      --clk_mem_mv=MV1,MV2,...     Définit la tension de la mémoire par GPU, en mV.  Non utilisé pour les GPU Navi et Big Navi.
      --clk_timing=V1,V2,...       Choisit parmi les jeux de timings mémoire proposés par le pilote.  Non disponible sur tous les GPU et
                                   tous les pilotes.
                              Exemple de ligne de commande partielle pour un système à quatre GPU avec une Rx Vega 64, une 580, une 5700XT et une
                              6800 qui minent ethash ou un algorithme similaire.   On n'indique la tension mémoire que pour la Vega et la 580, et on ne choisit
                              une valeur de timing du pilote que pour la Big Navi :
                              teamredminer.exe ... --clk_core_mhz=1100,1000,1275,1000 --clk_core_mv=875,850,725,675
                              --clk_mem_mhz=1107,2100,1820,2130 --clk_mem_mv=875,850,, --clk_timing=,,,1

Options de contrôle des ventilateurs :

      --fan_control(=CFG1,CFG2,...)  Cet argument active le contrôle des ventilateurs des GPU par le mineur.  TRM peut
                              ajuster automatiquement la vitesse des ventilateurs selon la température du cœur, de jonction et/ou de la mémoire.
                              Il est aussi possible de définir une vitesse fixe en pourcentage.
                              Chaque type de GPU dispose d'une configuration de ventilateur utilisée par défaut.  Vous pouvez
                              aussi bien remplacer la configuration par défaut d'un type de GPU que définir une
                              configuration précise pour chaque GPU du rig.
                              Une configuration de ventilateur comporte (au maximum) six valeurs séparées par le caractère ':' (deux-points).  Ces valeurs
                              sont : température cible du cœur, température cible de jonction, température cible de la mémoire, vitesse initiale du ventilateur en
                              pourcentage, vitesse minimale en pourcentage, vitesse maximale en pourcentage.  Chaque valeur peut être laissée vide.
                              Voici quelques exemples :
                              ::70:50:25   Température mémoire cible 70C, démarrage du ventilateur à 50 %, vitesse minimale 25 %.
                              55::::20:80  Température du cœur cible 55C, démarrage à la vitesse de la configuration par défaut,
                                           ventilateur toujours maintenu entre 20 % et 80 %.
                              55::75:80    Ajuste le ventilateur pour que le cœur reste <= 55C et la mémoire <= 75C, démarrage
                                           du ventilateur à 80 %.
                              :::100       Vitesse fixe de 100 %, jamais ajustée selon les températures.
                              La configuration de ventilateur d'un GPU est déterminée selon l'ordre de priorité suivant :
                              1. Une liste de configurations a été passée à l'argument --fan_control et contient une
                                 entrée pour le GPU X.
                              2. La configuration par défaut de ce type de GPU a été remplacée avec un
                                 paramètre --fan_default_<type>=...
                              3. La configuration de ventilateur par défaut intégrée pour ce type de GPU est utilisée.
                              Dans la liste ci-dessus, si la vitesse de démarrage du ventilateur manque dans la configuration retenue,
                              la valeur de la configuration suivante est utilisée.
                              REMARQUE : le contrôle des ventilateurs est une fonctionnalité bêta et ne fera pas mieux que ce que
                              permettent les pilotes.  Par exemple, sous Linux, les pilotes ne permettent souvent pas de forcer un
                              ventilateur à 100 % via le pwm de sysfs.
      --fan_default_polaris=CFG Définit la configuration par défaut de tous les GPU Polaris (450/460/550/560/470/480/570/580/590).
                              La valeur par défaut intégrée est 55:::50 : 55C pour le cœur et ventilateur démarrant à 50 %.
                              Remarque : ce réglage est aussi utilisé pour les GPU Tonga.
      --fan_default_vega=CFG    Définit la configuration par défaut de tous les GPU Vega (Vega 56/Vega 64).
                              La valeur par défaut intégrée est 55::70:50 : 55C pour le cœur, 70C pour la mémoire et ventilateur à 50 %.
      --fan_default_vega2=CFG   Définit la configuration par défaut de tous les GPU Radeon VII.
                              La valeur par défaut intégrée est 70::75:80 : 70C pour le cœur, 75C pour la mémoire et ventilateur à 80 %.
      --fan_default_navi=CFG    Définit la configuration par défaut de tous les Navi (Navi10).
                              La valeur par défaut intégrée est 60::80:70 : 60C pour le cœur, 80C pour la mémoire et ventilateur à 70 %.
      --fan_default_big_navi=CFG  Définit la configuration par défaut de tous les Big Navi (Navi21).
                              La valeur par défaut intégrée est 50:::70 : 50C pour le cœur et ventilateur à 70 %. La température
                              mémoire n'est pas incluse car le capteur correspondant manque dans la bibliothèque ADL de Windows.
      --fan_debug             Active l'affichage des journaux liés aux ajustements.
      --fan_no_restore        Désactive la restauration des profils de ventilateur d'origine à la fermeture du mineur.

Options du watchdog :

      --no_gpu_monitor      Désactive la surveillance des GPU via ADL (Windows) ou sysfs (Linux) pour la température et
                              la vitesse des ventilateurs.
      --temp_limit=TEMP     Définit la température du cœur à partir de laquelle le mineur arrête les GPU qui chauffent trop.
                              Par défaut : 85C.  Des valeurs propres à chaque GPU peuvent être indiquées dans une liste séparée par des virgules,
                              une valeur par GPU.  Si un GPU n'a pas de valeur définie, la première valeur de la liste
                              est utilisée.
      --temp_resume=TEMP    Définit la température du cœur en dessous de laquelle le mineur relance les GPU précédemment
                              arrêtés parce que leur cœur avait dépassé la limite.  Par défaut : 60C.  Des valeurs propres à chaque GPU
                              peuvent être indiquées dans une liste séparée par des virgules, une valeur par GPU.  Si un GPU n'a
                              pas de valeur définie, la première valeur de la liste est utilisée.
      --mem_temp_limit=TEMP Définit la température de la mémoire à partir de laquelle le mineur arrête les GPU qui chauffent trop.
                              Désactivé par défaut.  Utilisé uniquement si le GPU dispose d'un capteur de température mémoire.
                              Des valeurs propres à chaque GPU peuvent être indiquées dans une liste séparée par des virgules, une valeur par GPU.
                              Si un GPU n'a pas de valeur définie, la première valeur de la liste est utilisée.
      --mem_temp_resume=TEMP Définit la température de la mémoire en dessous de laquelle le mineur relance les GPU précédemment
                              arrêtés parce que leur mémoire avait dépassé la limite.  Désactivé par défaut.  Utilisé
                              uniquement si le GPU dispose d'un capteur de température mémoire.  Des valeurs propres à chaque GPU peuvent être indiquées
                              dans une liste séparée par des virgules, une valeur par GPU.  Si un GPU n'a pas de valeur définie,
                              la première valeur de la liste est utilisée.
      --watchdog_script(=X) Configure le watchdog des GPU pour qu'il arrête le mineur et exécute le script
                              de la plateforme indiqué, puis quitte immédiatement. Le script par défaut est watchdog.bat/watchdog.sh dans le
                              répertoire courant, mais un autre script peut être indiqué comme argument facultatif,
                              éventuellement avec un chemin absolu ou relatif.
      --watchdog_test       Teste le script du watchdog configuré en déclenchant la même action que pour un GPU planté
                              après environ 20 secondes de minage.
      --watchdog_disabled   Empêche l'exécution du watchdog. Permet de désactiver le watchdog sur les OS de minage
                              qui le lancent toujours activé.

Options Ethash :

      --eth_config=CONFIG   Configuration ethash manuelle du mineur.  CONFIG doit être de la forme [X][M][L].
                              La valeur [M] sélectionne le mode, qui peut être 'A', 'B' ou 'C'.
                              Le mode 'B' utilise davantage de mémoire et ne fonctionne que sur les cartes de 8+GB.
                              Le mode 'C' utilise davantage de mémoire et ne fonctionne que sur les cartes de 16+GB, comme la VII, avec
                              un système correctement configuré.  Voir ETHASH_TUNING_GUIDE.txt pour plus de détails.
                              La valeur [L] sélectionne l'intensité ; sa plage dépend de l'architecture du GPU.
                              Le préfixe [X] est facultatif et réservé aux Navi/Big Navi ; il active davantage d'opérations mémoire et
                              conduit à une valeur de réglage [L] plus basse. Il peut être utile lorsque le réglage automatique atteint
                              régulièrement une valeur proche du maximum possible pour le GPU.
                              Les deux valeurs sont facultatives, mais si [L] est indiqué, [M] doit l'être aussi.
                              Exemples de configurations : --eth_config=A
                                               --eth_config=B750
                                               --eth_config=XB
                              CONFIG peut aussi être une liste de valeurs séparées par des virgules, chacune
                              s'appliquant à un GPU. Par exemple : --eth_config=A,B750,,A288
                              Tout GPU sans configuration propre dans la liste utilise la première
                              configuration de la liste.
      --eth_variant_mode=X  Cet argument contrôle l'activation des modifications d'ethash pour ETC à partir de l'époque 390, décrites
                              dans l'ecip-1099. Les modes suivants sont disponibles :
                              pool      - Mode par défaut. Ne s'active que si le pool envoie un indicateur d'algorithme contenant etchash.
                                          Dès que cet indicateur est reçu, tous les jobs du pool sont considérés comme etchash, sauf si un autre
                                          indicateur d'algorithme contenant ethash est reçu.
                              etchash   - Mode etchash. Les époques >= 390 sont considérées comme etchash, les époques inférieures comme ethash. Les indicateurs
                                          d'algorithme du pool ne sont pas utilisés.
                              deduce    - Ignore les indicateurs d'algorithme du pool et applique seulement une heuristique basée sur l'heure système
                                          et les hauteurs et dates connues pour ETC et ETH. Ce mode devrait fonctionner comme une approche
                                          générique lorsque ETH atteindra l'époque 390 en janvier 2021. L'horloge système doit être exacte.
                                          Il devrait aussi gérer les configurations de profit switching qui basculent librement entre jobs ethash et
                                          etchash en servant de proxy à des pools sous-jacents.
                              auto      - Tant que le pool n'a pas envoyé d'indicateur d'algorithme, utilise le mode deduce. Dès qu'un indicateur
                                          est reçu, passe en mode pool.
                              ethash    - Mode ethash forcé. N'applique jamais l'ecip-1099.
                              force_etc - Mode etchash forcé. Applique toujours les règles de l'ecip-1099. À utiliser pour miner sur le testnet ETC.
      --eth_aggr_mode       Active automatiquement le mode 'B' pour toutes les cartes Polaris 8GB, sauf si l'argument
                              --eth_config leur attribue une autre configuration.  Cela revient à
                              passer manuellement tous les GPU Polaris 8GB du rig en mode 'B' avec --eth_config.
                              Pour la plupart des GPU, cela ajoute 0.1-0.2 MH/s de hashrate.  REMARQUE : 20 à 25 % des rigs deviennent moins
                              stables dans ce mode, c'est pourquoi il n'est pas activé par défaut.  Si des GPU
                              plantent, retirez cet argument et faites tourner les GPU en mode 'A'.
      --eth_stratum_mode=MODE Définit un mode stratum fixe pour les pools ethash.  Par défaut, le mineur essaie
                              de déterminer automatiquement le type de stratum pris en charge par le pool et utilise ce mode.
                              Cette détection automatique peut être contournée avec cette option.  MODE peut
                              prendre l'une des valeurs suivantes : stratum, nicehash, ethproxy.
      --eth_worker          Définit l'identifiant du worker envoyé au pool.  Ne s'applique qu'aux pools en mode stratum
                              ethproxy.
      --eth_hash_report=X   Contrôle l'envoi du hashrate aux pools configurés.  Cette valeur s'applique à tous les pools. Valeurs :
                              default   - le mineur décide selon le protocole stratum utilisé pour chaque pool.
                              force     - toujours envoyer le hashrate, même si le pool le rejette.
                              on        - envoyer un premier rapport de hashrate, puis désactiver pour tout pool qui rejette le message.
                              off       - ne jamais envoyer le hashrate.
      --eth_epoch           Teste une époque ethash précise. REMARQUE : le mineur passe alors automatiquement en mode benchmark, comme
                              si vous aviez ajouté --benchmark.
      --eth_alloc_epoch=N   Alloue dès le démarrage assez de mémoire pour l'époque indiquée.  Le mineur essaiera d'allouer davantage
                              si nécessaire plus tard pendant le minage.
      --eth_dag_buf=X,Y,... Le mineur peut allouer un seul ou deux buffers pour le DAG.  Pour l'instant, la valeur par défaut est AUTO.  Un buffer
                              unique est légèrement meilleur et permet une petite économie d'énergie sur tous les types de GPU.  Seuls les pilotes récents prennent en charge
                              une allocation unique de plus de 4GiB, en général à partir d'Adrenalin 20.9.1 et d'amdgpu-pro 20.x. Avec cet argument, le mineur
                              peut utiliser automatiquement le mode buffer unique quand c'est possible, ou bien forcer un buffer unique ou double
                              par GPU.  Valeurs possibles : A(uto), S(ingle), D(ual).  Vous pouvez indiquer une liste séparée par des virgules
                              pour tous les GPU du rig, ou une seule valeur pour tous.  Un GPU sans valeur dans la
                              liste utilise la première valeur.
      --eth_big_mode_adjust=X,Y,...  En modes B ou C, le mineur fonctionne d'autant mieux qu'il peut allouer de vram.  Malheureusement, les
                              pilotes n'indiquent pas précisément la quantité de mémoire allouable, surtout sous Windows.
                              Le mineur retient une marge prudente de 256MiB (Linux) et 512MiB (Windows) par rapport à
                              la taille de vram disponible.  Pour modifier cette valeur, utilisez cet argument en indiquant
                              une liste séparée par des virgules avec les valeurs d'un ou plusieurs GPU.  Les valeurs des GPU qui ne tournent pas en mode B/C sont
                              ignorées.  Si un GPU n'a pas de valeur dans la liste, la première valeur indiquée est utilisée.
                              L'intervalle autorisé est [-64, 2048]. Plus la valeur est élevée, moins le GPU alloue de vram.
      --eth_dag_slowdown=N  Ralentit la génération du DAG.  Indiquez un seul chiffre de 0-9. 0 signifie aucun ralentissement (comportement <= 0.7.9),
                              1 un ralentissement minimal, 9 le maximum.  Valeur par défaut : 4, pour un léger ralentissement.
      --eth_stagger         Échelonne les GPU lors de la construction d'un nouveau DAG.  Ménage les alimentations qui supportent mal
                              de passer de 0 à 100 % de charge sur tous les GPU en même temps.
      --eth_no_stagger      Désactive --eth_stagger.  C'est déjà le comportement par défaut depuis la 0.7.18.  Argument conservé uniquement
                              pour la rétrocompatibilité.
      --eth_ramp_up         Augmente progressivement l'intensité sur tous les GPU après la construction du DAG, la désactivation/réactivation d'un GPU ou une coupure réseau.
                              Peut aider les rigs qui plantent juste entre la construction du DAG et le début du minage.
      --eth_no_ramp_up      Désactive --eth_ramp_up.  C'est déjà le comportement par défaut depuis la 0.7.18.  Argument conservé uniquement
                              pour la rétrocompatibilité.
      --eth_direct_abort    Utilise un autre mécanisme pour interrompre les jobs GPU en cours.  Recommandé pour les Vega sous ROCm
                              afin de réduire les shares obsolètes (stale).  Ne s'applique qu'aux GPU Vega et Polaris du rig.
      --eth_dag_alloc_patch Sur certaines cartes mères au BIOS obsolète, des erreurs hw apparaissent, en général sur le premier ou le dernier GPU du système.
                              Utilisez cet argument pour forcer une stratégie d'allocation du DAG corrigée qui résout le problème dans la plupart des cas.
                              Mettre à jour le BIOS résout souvent le problème aussi.
      --eth_hashwatch(=M,M) Définit un hashrate min/max en MH/s attendu par le watchdog lorsque les GPU minent.  Si un GPU sort
                              de cette plage trop longtemps, il est considéré comme défaillant et le watchdog est déclenché.  Les
                              valeurs min/max par défaut sont 2 MH/s et 150 MH/s.  Pour l'activer avec les valeurs par défaut, utilisez
                              --eth_hashwatch.  Pour définir vos propres valeurs, utilisez par ex. --eth_hashwatch=1.25,60.  La même plage s'applique
                              à tous les GPU du rig.  Une valeur négative désactive la borne correspondante, par ex. --eth_hashwatch=-1,1000
                              pour gérer les resets de GPU qui produisent d'énormes hashrates fictifs, sans contrôle du minimum.
      --eth_dag_cache(=EPOCH) Active la sauvegarde des DAG eth des jobs d'époques différentes pour éviter de devoir les reconstruire
                              si des jobs des anciennes époques sont de nouveau reçus.  Au plus un DAG est sauvegardé si la mémoire du GPU
                              le permet.  C'est utile pour les pools qui alternent, comme le minage eth+zil.  Si vous voulez préconstruire une
                              époque précise dès le démarrage, ajoutez la valeur facultative. Les mineurs en bascule eth+zil devraient utiliser
                              --eth_dag_cache=0.  Pour l'instant, seules les époques ethash (et non etchash) peuvent être préconstruites.
      --eth_dag_cache_resv=MEM  Définit la quantité de mémoire GPU que le mineur essaie de laisser libre lorsque le cache du DAG
                              est activé (voir --eth_dag_cache).  L'argument MEM est la quantité de mémoire à laisser libre, en
                              mébioctets.  Valeur par défaut : 256.
      --eth_dag_cache_verify    Active la lecture et la vérification du cache du DAG après la construction d'un DAG.  Cela permet de détecter les cas
                              où le cache du DAG contenait des erreurs de bits et où le DAG obtenu est partiellement corrompu.  Nous avons constaté
                              ce problème de plus en plus souvent sur les Vega à mesure que le DAG grossissait.  En cas de détection, un nouveau buffer est
                              alloué pour le cache du DAG et la construction du DAG est relancée.
      --eth_micro_delay=VAL,VAL,...  Ajoute un délai (en microsecondes) lors de la remise en file du travail sur le ou les GPU.
                              Les alimentations plus faibles qui alimentent de nombreux GPU ne supportent parfois pas le « slew rate » lorsque plusieurs GPU
                              remettent du travail en file exactement au même moment.  Une valeur de 32, par exemple, adoucit suffisamment la transition
                              de l'absence de charge à 100 % de charge pour réduire le slew rate sur ces rigs.  Le symptôme typique de ce
                              problème est un blocage complet où le rig ne répond plus et doit être redémarré électriquement, mais il peut aussi
                              s'agir de plantages réguliers de GPU.  Valeurs valides : 0-256.  Les valeurs par GPU peuvent être indiquées dans une liste séparée par des virgules.
                              Les GPU sans valeur dans la liste utilisent la première valeur. Les valeurs par défaut de cet argument en
                              minage ethash sur un seul algorithme sont :
                                Polaris: 64
                                Vega:    0
                                Navi:    0
      --eth_ignore_abort_fail   Lorsque l'interruption d'un job échoue, c'est généralement dû à une intensité trop élevée, et le mineur
                              la réduit donc automatiquement.  Cette option _désactive_ ce comportement : l'intensité est conservée et
                              un avertissement est enregistré à la place.
      --eth_no_job_logs         Supprime tous les journaux des nouveaux jobs reçus du ou des pools.  S'applique à toutes les sessions de minage de la famille ethash,
                              c'est-à-dire qu'en configuration dual eth+zil, les journaux des pools eth et zil sont supprimés.  Les jobs du pool
                              qui passent à une nouvelle époque restent journalisés.
      --eth_smooth_power=X,Y,...  La méthode d'ordonnancement « smooth power » a été ajoutée dans la 0.10.0 et est disponible pour tous les types de GPU.
                              C'est généralement une bonne fonctionnalité, qui apporte un peu de hashrate et améliore aussi la stabilité dans la plupart
                              des cas ; elle est activée par défaut sur tous les GPU.  Cependant, certains rigs la supportent mal et
                              se mettent à planter.  Dans ce cas, utilisez cet argument pour contrôler la fonctionnalité GPU par GPU dans votre rig.
                              Valeurs valides : 0 ou 1. Pour un rig de 5 GPU, vous pouvez utiliser --eth_smooth_power=0,1,1,1,0 pour désactiver le smooth
                              power sur le premier et le dernier GPU.  Si vous n'indiquez pas de valeur pour un GPU, la première valeur de la liste
                              est utilisée.  Vous pouvez donc désactiver la fonctionnalité pour tout un rig avec --eth_smooth_power=0.

Options Progpow (kawpow, firopow) :

      --prog_config=CONFIG  Configuration progpow manuelle du mineur.  CONFIG doit être de la forme [M][L].
                              La valeur [M] sélectionne le mode, qui peut être 'A' ou 'B'.
                              Le mode 'B' offre généralement de meilleures performances, mais n'est disponible que pour
                              les Vega sous Linux et les Navi (Linux ou Windows).
                              La valeur [L] sélectionne l'intensité ; sa plage dépend de l'architecture du GPU.
                              Les deux valeurs sont facultatives, mais si [L] est indiqué, [M] doit l'être aussi.
                              Exemples de configurations : --prog_config=A
                                               --prog_config=B750
                              CONFIG peut aussi être une liste de valeurs séparées par des virgules, chacune
                              s'appliquant à un GPU. Par exemple : --prog_config=A,B750,,A288
                              Tout GPU sans configuration propre dans la liste utilise la première.
      --prog_height=VALUE   Définit une hauteur de bloc fixe pour les algorithmes progpow, à des fins de benchmark.  Le mineur passe alors
                              automatiquement en mode benchmark.
      --prog_strict         Force le mineur à toujours générer des kernels strictement exacts.  Par défaut, le mineur
                              génère des kernels assouplis qui demandent moins de calcul mais peuvent produire
                              occasionnellement des shares invalides.
      --prog_dag_slowdown=N  Ralentit la génération du DAG.  Indiquez un seul chiffre de 0-9.  0 signifie aucun ralentissement (comportement <= 0.7.9),
                              1 un ralentissement minimal, 9 le maximum.  Valeur par défaut : 4, pour un léger ralentissement.
      --prog_stagger         Voir --eth_stagger.
      --prog_ramp_up         Voir --eth_ramp_up.
      --prog_no_stagger      Voir --eth_no_stagger.
      --prog_no_ramp_up      Voir --eth_no_ramp_up.
      --prog_micro_tune=X,Y,... Cette option active une courte session de réglage pour chaque nouveau bloc de code aléatoire.  C'est important
                               pour que les GPU Polaris tournent à leur vitesse maximale.  Pour les Vega et les Navi, cela n'améliore généralement pas
                               les performances.  Le mode AUTO par défaut l'active pour tous les GPU Polaris et le désactive pour les autres.
                               La seule raison de le désactiver serait la stabilité.  La valeur de l'argument est une
                               liste séparée par des virgules, une valeur par GPU.  S'il manque une valeur pour un GPU, la valeur du
                               premier GPU est utilisée.  Notez que définir manuellement prog_config désactive de fait
                               aussi le micro-réglage.  Valeurs disponibles :
                               1 - DÉSACTIVER le micro-réglage progpow pour ce GPU.
                               2 - ACTIVER le micro-réglage progpow pour ce GPU.
                               3 - laisser le mineur décider s'il faut activer le micro-réglage (AUTO).
      --prog_hash_report    Force l'envoi du hashrate (comme pour ethash) à tous les pools.  C'est un alias de
                               --eth_hash_report=force, qui s'applique aussi puisque progpow et ethash utilisent le même
                               protocole de pool.

Options Cryptonight :

      --rig_id              Définit l'identifiant du rig envoyé au pool. Utilisé uniquement pour les
                              pools cryptonight.
      --cn_config=CONFIG    Configuration cryptonight manuelle du mineur.  CONFIG doit être de la forme
                              [P][I0][M][I1][:xyz], où [P] est un préfixe facultatif et [:xyz] un
                              suffixe facultatif.  Pour [P], seule la valeur 'L' est prise en charge, pour les GPU
                              d'entrée de gamme comme Lexa/Baffin.  [I0] et [I1] sont les intensités des threads, normalement
                              comprises entre 1 et 16, mais des valeurs plus élevées sont possibles pour les GPU de 16GB.  [M] est le
                              mode, qui peut être '.', -', '+' ou '*'.  Le mode '.' signifie que le mineur
                              doit choisir ou rechercher le meilleur mode.  Le mode '*' est un bon mode par défaut et
                              _devrait_ être utilisé si vous minez sur une Vega 56/64 avec des timings mémoire modifiés.  Les
                              exceptions à cette règle sont les variantes à petit pad (cnv8_trtl et cnv8_upx2), qui
                              doivent toujours utiliser '+'. Pour les GPU Polaris, seuls les modes '-' et '+' sont disponibles.

                              REMARQUE : le réglage automatique a été ajouté dans TRM 0.5.0, ce qui rend la configuration manuelle
                              des modes CN inutile, sauf dans de rares cas particuliers.  Pour plus d'informations,
                              consultez la documentation sur le réglage et les guides pratiques fournis avec la version.

                              Exemples de configurations : --cn_config=15*15:AAA
                                               --cn_config=14-14
                                               --cn_config=L4+3
                              CONFIG peut aussi être une liste de valeurs séparées par des virgules, chacune
                              s'appliquant à un GPU. Par exemple : --cn_config=8-8,16+14:CBB,15*15,14-14
                              Tout GPU sans configuration propre dans la liste utilise la première
                              configuration de la liste.
      --no_cpu_check        Désactive la vérification par le CPU des shares trouvés avant leur envoi au pool.
                              Remarque : seuls les algorithmes CN prennent actuellement en charge la vérification par le CPU.
      --no_lean             Désactive le mode lean CN, qui augmente progressivement le nombre de threads au démarrage ou au redémarrage après
                              des problèmes réseau ou un bridage dû à la température du GPU.
      --no_interleave=DEVS  Liste les GPU sur lesquels la logique d'entrelacement des threads CN ne doit pas être utilisée.
                              L'argument est une liste de périphériques séparés par des virgules, comme pour l'option -d ci-dessus.
                              Utilisez cet argument si un ou plusieurs périphériques obtiennent un moins bon hashrate avec beaucoup
                              de messages de journal sur l'ajustement de l'entrelacement.
      --alloc_patch=DEVS    Liste les GPU qui perdent du hashrate entre TRM v0.4.5 et les versions suivantes. Avec cet
                              argument, une stratégie d'allocation mémoire plus simple est utilisée et l'ancien hashrate (plus élevé) devrait
                              être retrouvé. Le mode de réglage automatique reste utilisable.
      --auto_tune=MODE      Active le mode de réglage automatique au démarrage. Disponible uniquement pour les variantes CN. MODE doit
                              être NONE, QUICK ou SCAN. Le mode QUICK teste quelques configurations connues pour être bonnes
                              et se termine en moins d'1 min. Le mode SCAN teste toutes les combinaisons possibles et
                              dure 20-30 min. Avec MODE à NONE, le réglage automatique est désactivé. Le mode par défaut
                              est QUICK.
      --auto_tune_runs(=N)  Effectue plusieurs passes de réglage automatique, en réduisant à chaque fois d'une unité les pads utilisés -1
                              dans l'un des threads (15+15 -> 15+14 -> 14+14 -> 14+13 -> ...). Vous pouvez indiquer
                              explicitement le nombre de passes ou laisser le mineur choisir une valeur par défaut selon le type de GPU (généralement 3-4).
      --auto_tune_exit      Si cette option est présente, le mineur quitte une fois le réglage automatique terminé. C'est pratique
                              pour rechercher les réglages optimaux, puis utiliser l'argument de ligne de commande obtenu,
                              affiché par le mineur.
      --allow_large_alloc   Si cette option est présente et que le pilote indique qu'il y a assez de vram GPU disponible, le mineur
                              est plus agressif lors de l'allocation mémoire initiale. En pratique, cette option
                              signifie que les GPU Vega sous Linux commencent le réglage automatique à 16*15 plutôt
                              qu'à 16*14 ou 15*15.

Options MTP :

      --allow_all_devices   Certains algorithmes ne peuvent pas être minés sur des GPU de 4GB, par exemple. Ces GPU sont désactivés automatiquement
                              par le mineur. Cet argument contourne ce comportement et autorise le minage sur tous les périphériques indiqués
                              ou détectés.

Options X16* :

      --hash_order=VALUE    Définit un ordre de hachage fixe pour des algorithmes comme x16r, à des fins de benchmark.
                              Ce réglage fait automatiquement passer le mineur en mode benchmark.
                              L'ordre de hachage standard du benchmark pour x16r est --hash_order=0123456789abcdef.

Options Nimiq :

      --nimiq_worker=VALUE  Définit le nom du worker/périphérique nimiq transmis au(x) pool(s).
      --nimiq_no_proxy      Désactive le proxy Nimiq automatique lancé comme processus séparé. L'hôte
                              et le port transmis au mineur doivent alors pointer vers un proxy.
      --nimiq_proxy=VALUE   Remplace le chemin par défaut du proxy Nimiq. Par défaut : trm_nimiq_proxy-win.exe
                              et trm_nimiq_proxy-linux dans le répertoire actuel du mineur.
      --nimiq_port=VALUE    Remplace le port local par défaut (4444) utilisé par le proxy Nimiq. Utile si votre
                              système utilise déjà le port 4444 pour un autre service tcp/ip.

Options Verthash :

      --verthash_file=FILE  Définit le nom du fichier utilisé pour charger/enregistrer le fichier de données verthash.  Si cette option est
                              indiquée avec l'algorithme verthash, le mineur essaie de charger les données verthash
                              depuis ce fichier.  Si le fichier n'existe pas, le mineur génère les données verthash
                              puis les enregistre dans le fichier pour une utilisation ultérieure.  Si cette option n'est pas indiquée, le
                              mineur génère les données verthash en mémoire système à chaque démarrage.
      --verthash_max_uploads=N  Certaines cartes mères ont des problèmes lorsque tous les GPU du rig chargent la table verthash
                              en même temps.  Cet argument limite le nombre de GPU qui chargent
                              la table simultanément au démarrage.  Valeurs autorisées : 1-32.  Valeur par défaut : 4.

Options Autolykos2 :

      --autolykos_mem_adjust=N  Définit la quantité de mémoire, en MiB, que le mineur doit laisser libre lors de l'allocation
                              des buffers GPU pour autolykos.  Valeur par défaut : 384 sous Linux et 512 sous Windows.  Pour les GPU
                              auxquels un écran est branché, la valeur par défaut est augmentée de 512.  En minage dual avec ZIL, la
                              valeur par défaut est augmentée de 1024.  L'option accepte aussi une liste de valeurs séparées par des virgules,
                              chacune s'appliquant à un GPU.  Si une valeur vide figure
                              dans la liste, la valeur par défaut est utilisée pour ce GPU.  Si aucune valeur n'est indiquée pour un GPU,
                              la première valeur de la liste est utilisée.  La vram utilisée doit contenir à la fois les buffers
                              principaux et un éventuel buffer préconstruit pour la hauteur suivante.  Par exemple :
                                    --autolykos_mem_adjust=256,512,,256
      --autolykos_prebuild=N  Configure la vitesse de préconstruction du pad pour la hauteur suivante.  Une valeur plus élevée accélère la préconstruction,
                              mais provoque de plus fortes variations de consommation et probablement une baisse de hashrate plus importante tant que la préconstruction
                              est en cours.  Valeurs valides : 0-9, où 0 signifie aucune préconstruction et 9 la variante la plus rapide.
                              Valeur par défaut : 3 ou 4 selon le GPU.  Vous pouvez indiquer une seule valeur pour tous les
                              GPU, ou une liste de valeurs par GPU séparées par des virgules.
      --autolykos_slowdown=N  Ralentit la construction du pad.  Valeurs valides : 0-100. Par défaut : 0, aucun
                              ralentissement.
      --autolykos_ignore_diff Ignore la difficulté envoyée par le pool et utilise uniquement la cible de 256 bits fournie dans les jobs.
                              Certains pools ne suivent pas l'implémentation de référence du pool ERGO ; dans ce cas, cet
                              argument _pourrait_ aider. REMARQUE : il s'applique à tous les pools.

Options de minage dual ZIL :

      --zil_start or --zil  Démarre la configuration du minage dual ZIL.  Tous les arguments placés entre celui-ci et le marqueur --zil_end
                              s'appliquent au minage ZIL plutôt qu'à l'algorithme principal.  L'algorithme principal est censé
                              avoir été configuré dans les arguments précédents.  L'idée est de pouvoir ajouter une configuration --zil ... --zil_end
                              à n'importe quelle configuration TRM fonctionnelle, et que tout marche immédiatement.
                              Cet argument applique automatiquement une série de réglages par défaut adaptés à ZIL :
                               - Copie en cache du DAG de l'époque 0 de ZIL.
                               - Ajustement de la mémoire allouée à l'algorithme principal pour faire de la place au DAG ZIL.
                               - Choix du mode A d'ethash pour le minage ZIL.
                              La configuration minimale consiste à n'indiquer qu'un pool ZIL qui accepte que le mineur ignore
                              les jobs de la cryptomonnaie principale et ne mine que pendant les fenêtres ZIL.  Voici un exemple pour ezil.me :
                              --zil -o stratum+tcp://eu.ezil.me:5555 -u <eth wallet>.<zil wallet>.<worker name> -p x --zil_end
                              Pour plus d'informations, lisez le guide du minage dual ZIL fourni avec la version de TRM.
      --zil_end             Indique la fin de la configuration du minage ZIL ; tous les arguments suivants concernent l'algorithme
                              principal.  Cet argument n'est pas strictement nécessaire, mais il est recommandé sur les distributions de minage, car
                              l'utilisateur n'a aucune garantie sur les arguments que la distribution ajoutera automatiquement à la fin de la ligne
                              de commande.
      --stats_mode=single/dual  Avec le minage dual ZIL, l'affichage des statistiques est par défaut dupliqué pour ajouter les informations
                              du minage ZIL.  Certains outils qui analysent la sortie ou les fichiers journaux de TRM peuvent s'y perdre.
                              Pour revenir à l'affichage par défaut, ajoutez --stats_mode=single.

Options TON :

      --ton_pool_mode=X     Indique le dialecte de minage TON utilisé.  S'il n'est pas défini, le mineur essaie de déduire le bon choix
                              à partir du nom d'hôte du pool.  Options disponibles :
                              toncoinpool - utiliser le protocole stratum wss de toncoinpool.
                              icemining   - utiliser le protocole stratum d'ice mining sur tcp/ip.
                              tonpool     - utiliser la version de tonpool du protocole stratum d'ice mining sur wss.
      --wss_force_proxy     Force l'activation du proxy wss automatique, lancé comme processus séparé, utilisé pour les pools TON dont le
                              protocole de minage passe par wss.  Le mineur l'active normalement tout seul, mais si une adresse IP brute
                              ou un nom d'hôte alias est utilisé pour la connexion, cet argument peut être nécessaire.
      --wss_no_proxy        Désactive le proxy wss automatique, lancé comme processus séparé, utilisé pour les pools TON dont le
                              protocole de minage passe par wss. L'hôte et le port transmis au mineur doivent alors pointer
                              vers un proxy.
      --wss_proxy=VALUE     Remplace le chemin par défaut du proxy wss. Par défaut : trm_nimiq_proxy-win.exe
                              et trm_nimiq_proxy-linux dans le répertoire actuel du mineur, car il n'était à l'origine utilisé que pour
                              Nimiq.
      --wss_port=VALUE      Remplace le port local par défaut (4444) utilisé par le proxy wss. Utile si votre
                              système utilise déjà le port 4444 pour un autre service tcp/ip.

Options de minage dual avec Ethash :

      --ton_start or --ton  Démarre la configuration du minage dual TON.  Tous les arguments placés entre celui-ci et le marqueur --ton_end
                              s'appliquent au minage TON plutôt qu'à l'algorithme principal, en général ethash.  Ethash est censé
                              avoir été configuré dans les arguments précédents.  L'idée est de pouvoir ajouter une configuration --ton ... --ton_end
                              à n'importe quelle configuration TRM fonctionnelle, et que tout marche immédiatement.
                              La configuration minimale consiste à n'indiquer qu'un pool TON.  Consultez le guide du minage TON pour connaître
                              les pools pris en charge. Voici un exemple pour icemining, avec l'adresse de son pool bêta :
                              --ton -o stratum+tcp://ton.hashrate.to:4003 -u <ton wallet>.<worker name> -p x --ton_end
                              Pour plus d'informations, lisez le guide du minage dual TON fourni avec la version de TRM.
      --ton_end             Indique la fin de la configuration du minage TON ; tous les arguments suivants concernent l'algorithme
                              principal.  Cet argument n'est pas strictement nécessaire, mais il est recommandé sur les distributions de minage, car
                              l'utilisateur n'a aucune garantie sur les arguments que la distribution ajoutera automatiquement à la fin de la ligne
                              de commande.
      --kas_start or --kas  Démarre la configuration du minage dual Kaspa.  Tous les arguments placés entre celui-ci et le marqueur --kas_end
                              s'appliquent au minage Kaspa plutôt qu'à l'algorithme principal, en général ethash.  Ethash est censé
                              avoir été configuré dans les arguments précédents.  L'idée est de pouvoir ajouter une configuration --kas ... --kas_end
                              à n'importe quelle configuration TRM fonctionnelle, et que tout marche immédiatement.
                              La configuration minimale consiste à n'indiquer qu'un pool Kaspa.  Voici un exemple :
                              --kas -o stratum+tcp://pool.woolypooly.com:3112 -u <kaspa wallet>.<worker name> -p x --kas_end
      --kas_end             Indique la fin de la configuration du minage Kaspa ; tous les arguments suivants concernent l'algorithme
                              principal.  Cet argument n'est pas strictement nécessaire, mais il est recommandé sur les distributions de minage, car
                              l'utilisateur n'a aucune garantie sur les arguments que la distribution ajoutera automatiquement à la fin de la ligne
                              de commande.
      --dual_intensity=X,Y,Z,... Cet argument ajuste l'intensité du minage dual avec un facteur compris entre 0.0 et 1.0, où 1.0
                              signifie miner autant que possible l'algorithme dual.  Cette option est recommandée pour réduire la consommation
                              sans baisser la fréquence du cœur, ce qui affecterait aussi le hashrate ethash.

                              L'argument s'indique soit sous forme d'une valeur globale unique, soit d'une liste de valeurs par GPU.  Exemples :

                                --dual_intensity=0.75            Tous les GPU utilisent 75 % de la disponibilité GPU maximale possible pour TON.
                                --dual_intensity=0.75,1.0,0.5    Valeurs distinctes pour les trois premiers GPU du rig ; les GPU restants
                                                                 utilisent la première valeur, soit 75 %.

      --dual_tuner_step=X   Définit le pas utilisé par le tuner dual pour tester différentes intensités de configuration eth.  Une valeur
                              plus faible donne des résultats plus précis mais prend aussi plus de temps.  Valeurs valides : 1,2,4,8,16,32,64.
      --dual_tuner_period=X Définit le nombre de secondes pendant lesquelles le tuner dual teste chaque configuration.  Par défaut : 7 s.
      --dual_tuner_weights=X:Y:Z  Le tuner du minage dual a besoin de pondérations indiquant ce que valent 1 MH/s de l'algorithme principal et de l'algorithme
                              dual.  Le mineur intègre des valeurs par défaut, valables au moment où chaque algorithme a été implémenté
                              et ajouté, mais comme les hashrates des réseaux et les cours évoluent, il peut être nécessaire d'en fournir de nouvelles.
                              Cet argument prend trois valeurs, toutes censées être des nombres positifs :
                                X    Score pour 1 MH/s de l'algorithme principal (en général ethash).
                                Y    Score pour 1 MH/s de l'algorithme secondaire (en général TON ou Kaspa).
                                Z    Coût par W de consommation mesurée. Nous recommandons de le laisser à zéro pour l'instant.
                              Exemple pour ETH+TON :
                                Basé sur une valeur relative manuelle : chaque MH/s d'ETH vaut 100 MH/s de TON/Kaspa
                                --dual_tuner_weights=100:1:0
                                Basé sur les calculateurs de minage : 0.0437 $ pour 1 MH/s d'ETH, 0.0005476 $ pour 1 MH/s de TON/Kaspa
                                --dual_tuner_weights=0.0437:0.0005476:0

Options FPGA :

      --fpga_devices=LIST   Définit les périphériques FPGA à utiliser parmi la liste détectée. LIST est une liste, séparée par des virgules, soit
                              d'index de périphériques, soit de DNA de périphériques tels qu'affichés par --list_devices.
                                Exemples :  -d 0,1,2,4
                                            -d 40020000013ae32135111111,40020000013ae32135222222,40020000013ae32135333333
                              Si rien n'est indiqué, tous les périphériques FPGA disponibles sont utilisés.
      --fpga_clk_core=LIST  Définit les fréquences du cœur des périphériques FPGA.  Les fréquences s'indiquent sous forme de
                              liste de valeurs en mégahertz séparées par des virgules, chacune s'appliquant à un périphérique FPGA.
                              Si la liste est plus courte que le nombre total de périphériques, les périphériques restants utilisent la
                              première valeur de la liste.  Par exemple, --fpga_clk_core=600,620 applique 600MHz au
                              FPGA 0 et 620MHz au FGPA 1.  Si des périphériques FPGA 2+ sont présents, ils sont réglés à 600MHz.
      --fpga_clk_mem=LIST   Définit les fréquences mémoire des périphériques FPGA.  Même format que --fpga_clk_core.
      --fpga_vcc_int=LIST   Définit la tension vcc_int sur les cartes qui le permettent.  Les tensions s'indiquent sous forme de
                              liste de valeurs en millivolts (mV) séparées par des virgules, chacune s'appliquant à une carte.
                              Si la liste est plus courte que le nombre total de périphériques, les périphériques restants utilisent la
                              première valeur de la liste.  Par exemple, --fpga_vcc_int=700,800 applique 700mV de vcc_int au
                              FPGA 0 et 800mV de vcc_int au FGPA 1.  Si des périphériques FPGA 2+ sont présents, ils sont réglés à 700mV.
      --fpga_vcc_bram=LIST  Définit la tension vcc_bram sur les cartes qui le permettent.  Même format que --fpga_vcc_int.
      --fpga_vcc_mem=LIST   Définit la tension mémoire/HBM sur les cartes qui le permettent.  Même format que --fpga_vcc_int.
      --fpga_update_fw      Active la mise à jour du firmware du contrôleur satellite des cartes C1100 avec le firmware TRM personnalisé,
                              afin de prendre en charge des fonctions comme le contrôle de la tension à chaud. Seules les cartes sélectionnées avec
                              l'option --fpga_devices qui n'ont pas la dernière version du firmware sont mises à jour.
                              ***** ATTENTION : veillez à ne pas interrompre la mise à jour du firmware !              *****
                              *****   Une interruption peut rendre la carte inutilisable et très difficile à récupérer. *****
      --fpga_allow_unsafe=LIST Désactive les limites de sécurité par défaut pour les FPGA indiqués.  Les périphériques s'indiquent sous forme de
                              liste de valeurs DNA séparées par des virgules, par ex. --fpga_allow_unsafe=40020000013ae32135111111
                              ***** ATTENTION : dépasser les limites de sécurité peut ENDOMMAGER DÉFINITIVEMENT le périphérique ! *****
      --fpga_tcore_limit=LIST Définit les limites souples de température du cœur des FPGA.  Si la température du cœur du FPGA dépasse la
                              valeur indiquée, le mineur baisse les fréquences du FPGA pour ramener la température du cœur sous
                              cette valeur.  Les valeurs sont en degrés Celsius, avec un format de liste semblable à --fpga_clk_core.
      --fpga_tmem_limit=LIST Définit les limites souples de température mémoire des FPGA.  Voir --fpga_tcore_limits pour la description.
      --fpga_ivccint_limit=LIST Définit les limites souples de courant du régulateur de tension VCCINT.  Voir --fpga_tcore_limits pour la description.
      --fpga_ivccbram_limit=LIST Définit les limites souples de courant du régulateur de tension VCCBRAM.  Voir --fpga_tcore_limits pour la description.
      --fpga_max_jtag_mhz=XY.Z  Définit la fréquence maximale autorisée pour la communication jtag des FPGA.  Par défaut : 30.0 MHz.
      --fpga_eth_clk_dag=LIST Définit les fréquences du cœur des FPGA utilisées pendant la construction du DAG Ethash. Par défaut, elles
                              sont réglées à 90 % de la fréquence normale du cœur. Même format que --fpga_clk_core.

Téléchargement Team Red Miner

0.10.21